package com.intel.software.academic.program;

import java.util.ArrayList;
import java.util.List;
import android.content.Context;
import android.hardware.usb.UsbDevice;
import android.hardware.usb.UsbDeviceConnection;
import android.hardware.usb.UsbManager;

/**
 * PololuCard object
 * To connect and initialize interfaces with a Pololu card
 * @version 01/24/2014
 * @author Cédric Andreolli
 * @author modified by Nicolas Vailliet
 * Intel Corporation, 2014
 */
public class PololuCard implements IPololuCard{
	
	private List<Signal> signalList;
	private UsbManager usbManager;
	private UsbDeviceConnection connection;
	private UsbDevice device;
	
	/**
	 * Builds a PololuCard object with the application context and the type of board
	 * @param context
	 * @param type
	 * @return
	 * @throws InterruptedException
	 */
	public static PololuCard createCard(Context context, PololuCardType type) throws InterruptedException
	{
		switch (type) {
		case MICRO_MAESTRO:
			return new PololuCard(context, 6);
		case MINI_MASTREO_12:
			return new PololuCard(context, 12);
		case MINI_MASTREO_18:
			return new PololuCard(context, 18);
		case MINI_MASTREO_24:
			return new PololuCard(context, 24);
		default:
			return new PololuCard(context, 6);
		}
	}
	
	/**
	 * PololuCard constructor
	 * @param context, the application context
	 * @param servoNumber, how many servos are available on this Pololu board
	 * @throws InterruptedException
	 */
	private PololuCard(Context context, int servoNumber) throws InterruptedException
	{
		signalList = new ArrayList<Signal>();
		usbManager = (UsbManager) context.getSystemService(Context.USB_SERVICE);
		
		for(UsbDevice device : usbManager.getDeviceList().values())
		{
			this.device = device;
			break;
		}

		connection = usbManager.openDevice(this.device);
		DisplayedLogger.info("Device serial number is: "+connection.getSerial());
		
		for(int i=0; i<servoNumber; i++)
			signalList.add(new Signal(i, connection));
	}
	

	
}
