package com.intel.software.academic.program;

import android.hardware.usb.UsbDeviceConnection;

/**
 * Signal object
 * Specifies actions specific to each signal
 * @version 01/24/2014
 * @author Cédric Andreolli
 * @author Nicolas Vailliet
 * Intel Corporation, 2014
 */

public class Signal implements ISignal {

	private int signal_id;
	/** Usb connection to the board **/
	private UsbDeviceConnection connection;
	
	/**
	 * Constructor
	 * @param num, channel number
	 * @param connection, usb connection
	 */
	Signal(int sigid, UsbDeviceConnection connection)
	{
		this.signal_id = sigid;
		this.connection = connection;
	}
	
	/**
	 * Sends a command to the board
	 * @param command, the command type (cf interface)
	 * @param channel, channel concerned by the command
	 * @param value, to be sent
	 */
	public void sendCommand(int command, int channel, int value) {
		if(connection != null)
			connection.controlTransfer(0x40, command, value, channel, null, 0, 5000);
		// TODO Auto-generated method stub
	}
	
	/**
	 * Sends a request to the board
	 * @param command, the request type (cf interface)
	 * @param channel, channel concerned by the request
	 * @param value, to be sent
	 */
	@Override
	public void sendRequest(int command, int channel, int value) {
		if(connection != null)
			connection.controlTransfer(0x40, command, value, channel, null, 0, 5000);
		// TODO Auto-generated method stub
	}
	
	/**
	 * Set the position
	 * @param position, value in quarter-microseconds
	 */
	@Override
	public void setPosition(int position) {
		sendCommand(PololuConstants.USB_SET_POSITION, signal_id, position*4);
		// TODO Auto-generated method stub
	}

	/**
	 * Set the target
	 * @param target, value in quarter-microseconds
	 */
	@Override
	public void setTarget(int target) {
		sendCommand(PololuConstants.USB_SET_POSITION, signal_id, target*4);
		// TODO Auto-generated method stub
	}
	
	/**
	 * Set the speed
	 * @param speed, value to send
	 */
	@Override
	public void setSpeed(int speed) {
		sendCommand(PololuConstants.USB_SET_SPEED, signal_id, speed);
		// TODO Auto-generated method stub
	}

	/**
	 * Set the acceleration
	 * @param acceleration, value to send
	 */
	@Override
	public void setAcceleration(int acceleration) {
		sendCommand(PololuConstants.USB_SET_ACCELERATION, signal_id, acceleration);
		// TODO Auto-generated method stub
	}

	@Override
	public int getPosition() {
		// TODO Auto-generated method stub
		return 0;
	}

	@Override
	public String getSignalName() {
		switch (signal_id) {
		case SIGNAL_AILERON:
			return "AILERON";
		case SIGNAL_ELEVATOR:
			return "ELEVATOR";
		case SIGNAL_THROTTLE:
			return "THROTTLE";
		case SIGNAL_RUDDER:
			return "RUDDER";
		default:
			return null;
			}
	}

}
